==> lib-1.0.1.tgz: package/README.md <==
CodeEngine lib
======================================

[![Cross-Platform Compatibility](https://engine.codes/img/badges/os-badges.svg)](https://github.com/CodeEngineOrg/code-engine-lib/blob/master/.github/workflows/CI-CD.yaml)
[![Build Status](https://github.com/CodeEngineOrg/code-engine-lib/workflows/CI-CD/badge.svg)](https://github.com/CodeEngineOrg/code-engine-lib/blob/master/.github/workflows/CI-CD.yaml)

[![Coverage Status](https://coveralls.io/repos/github/CodeEngineOrg/code-engine-lib/badge.svg?branch=master)](https://coveralls.io/github/CodeEngineOrg/code-engine-lib)
[![Dependencies](https://david-dm.org/CodeEngineOrg/code-engine-lib.svg)](https://david-dm.org/CodeEngineOrg/code-engine-lib)

[![npm](https://img.shields.io/npm/v/@code-engine/lib.svg)](https://www.npmjs.com/package/@code-engine/lib)
[![License](https://img.shields.io/npm/l/@code-engine/lib.svg)](LICENSE)
[![Buy us a tree](https://img.shields.io/badge/Treeware-%F0%9F%8C%B3-lightgreen)](https://plant.treeware.earth/CodeEngineOrg/code-engine-lib)



This is the core library for [CodeEngine](https://engine.codes/). It exports the `CodeEngine` class, which manages plugins, worker threads, events, builds, and watching functionality.

> **NOTE:** This is an **internal library** that is only intended to be used by CodeEngine. Using it outside of CodeEngine is discouraged. Use the [code-engine npm package](https://www.npmjs.com/package/code-engine) instead.



Usage
--------------------------
This package exports a `CodeEngine` class.  See the [Programmatic API wiki page](https://github.com/CodeEngineOrg/code-engine/wiki/Programmatic-API) for details about how to use this class.



Contributing
--------------------------
Contributions, enhancements, and bug-fixes are welcome!  [File an issue](https://github.com/CodeEngineOrg/code-engine-lib/issues) on GitHub and [submit a pull request](https://github.com/CodeEngineOrg/code-engine-lib/pulls).

#### Building
To build the project locally on your computer:

1. __Clone this repo__<br>
`git clone https://github.com/CodeEngineOrg/code-engine-lib.git`

2. __Install dependencies__<br>
`npm install`

3. __Build the code__<br>
`npm run build`

4. __Run the tests__<br>
`npm test`



License
--------------------------
@code-engine/lib is 100% free and open-source, under the [MIT license](LICENSE). Use it however you want.

This package is [Treeware](http://treeware.earth). If you use it in production, then we ask that you [**buy the world a tree**](https://plant.treeware.earth/CodeEngineOrg/code-engine-lib) to thank us for our work. By contributing to the Treeware forest you’ll be creating employment for local families and restoring wildlife habitats.



Big Thanks To
--------------------------
Thanks to these awesome companies for their support of Open Source developers ❤

[![Travis CI](https://engine.codes/img/badges/travis-ci.svg)](https://travis-ci.com)
[![SauceLabs](https://engine.codes/img/badges/sauce-labs.svg)](https://saucelabs.com)
[![Coveralls](https://engine.codes/img/badges/coveralls.svg)](https://coveralls.io)

==> lib-1.0.2.tgz: package/README.md <==
CodeEngine lib
======================================

[![Cross-Platform Compatibility](https://engine.codes/img/badges/os-badges.svg)](https://github.com/CodeEngineOrg/code-engine-lib/actions)
[![Build Status](https://github.com/CodeEngineOrg/code-engine-lib/workflows/CI-CD/badge.svg)](https://github.com/CodeEngineOrg/code-engine-lib/actions)

[![Coverage Status](https://coveralls.io/repos/github/CodeEngineOrg/code-engine-lib/badge.svg?branch=master)](https://coveralls.io/github/CodeEngineOrg/code-engine-lib)
[![Dependencies](https://david-dm.org/CodeEngineOrg/code-engine-lib.svg)](https://david-dm.org/CodeEngineOrg/code-engine-lib)

[![npm](https://img.shields.io/npm/v/@code-engine/lib.svg)](https://www.npmjs.com/package/@code-engine/lib)
[![License](https://img.shields.io/npm/l/@code-engine/lib.svg)](LICENSE)
[![Buy us a tree](https://img.shields.io/badge/Treeware-%F0%9F%8C%B3-lightgreen)](https://plant.treeware.earth/CodeEngineOrg/code-engine-lib)



This is the core library for [CodeEngine](https://engine.codes/). It exports the `CodeEngine` class, which manages plugins, worker threads, events, builds, and watching functionality.

> **NOTE:** This is an **internal library** that is only intended to be used by CodeEngine. Using it outside of CodeEngine is discouraged. Use the [code-engine npm package](https://www.npmjs.com/package/code-engine) instead.



Usage
--------------------------
This package exports a `CodeEngine` class.  See the [Programmatic API wiki page](https://github.com/CodeEngineOrg/code-engine/wiki/Programmatic-API) for details about how to use this class.



Contributing
--------------------------
Contributions, enhancements, and bug-fixes are welcome!  [Open an issue](https://github.com/CodeEngineOrg/code-engine-lib/issues) on GitHub and [submit a pull request](https://github.com/CodeEngineOrg/code-engine-lib/pulls).

#### Building
To build the project locally on your computer:

1. __Clone this repo__<br>
`git clone https://github.com/CodeEngineOrg/code-engine-lib.git`

2. __Install dependencies__<br>
`npm install`

3. __Build the code__<br>
`npm run build`

4. __Run the tests__<br>
`npm test`



License
--------------------------
@code-engine/lib is 100% free and open-source, under the [MIT license](LICENSE). Use it however you want.

This package is [Treeware](http://treeware.earth). If you use it in production, then we ask that you [**buy the world a tree**](https://plant.treeware.earth/CodeEngineOrg/code-engine-lib) to thank us for our work. By contributing to the Treeware forest you’ll be creating employment for local families and restoring wildlife habitats.



Big Thanks To
--------------------------
Thanks to these awesome companies for their support of Open Source developers ❤

[![Travis CI](https://engine.codes/img/badges/travis-ci.svg)](https://travis-ci.com)
[![SauceLabs](https://engine.codes/img/badges/sauce-labs.svg)](https://saucelabs.com)
[![Coveralls](https://engine.codes/img/badges/coveralls.svg)](https://coveralls.io)
